@@ -4,6 +4,8 @@ use strict;
 use warnings;
 use Data::Dumper;
 use File::Temp;
+use File::Copy qw(copy);
+use File::Path qw(make_path);
 use Cwd;
 use Expect;
 use RPM::Packager::Utils;
@@ -14,11 +16,11 @@ RPM::Packager - Manifest-based approach for building RPMs
 
 =head1 VERSION
 
-Version 0.1.2
+Version 0.2.0
 
 =cut
 
-our $VERSION = 'v0.1.2';
+our $VERSION = 'v0.2.0';
 
 =head1 SYNOPSIS
 
@@ -87,14 +89,10 @@ Constructor.  Pass in a hash containing manifest info.
 
 sub new {
     my ( $class, %args ) = @_;
-    chomp( my $fpm   = `which fpm 2>/dev/null` );
-    chomp( my $mkdir = `which mkdir` );
-    chomp( my $cp    = `which cp` );
+    chomp( my $fpm = `which fpm 2>/dev/null` );
 
     my $self = {
         fpm     => $fpm,
-        mkdir   => $mkdir,
-        cp      => $cp,
         cwd     => getcwd(),
         tempdir => File::Temp->newdir(),
         %args
@@ -133,10 +131,14 @@ sub copy_to_tempdir {
     my $tempdir = $self->{tempdir};
 
     for my $key ( keys %hash ) {
+        my @files      = RPM::Packager::Utils::find_files("$cwd/$key");
         my $dst        = $hash{$key};
         my $target_dir = "$tempdir$dst";
-        system("$self->{mkdir} -p $target_dir");
-        system("$self->{cp} -r $cwd/$key/* $target_dir");
+        make_path($target_dir);
+
+        for my $file (@files) {
+            copy $file, $target_dir;
+        }
     }
     return 1;
 }
